% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getExperimentCrossCorrelation.R
\name{getExperimentCrossCorrelation}
\alias{getExperimentCrossCorrelation}
\alias{getExperimentCrossCorrelation,MultiAssayExperiment-method}
\alias{getExperimentCrossCorrelation,SummarizedExperiment-method}
\alias{testForExperimentCrossCorrelation}
\alias{testForExperimentCrossCorrelation,ANY-method}
\title{Calculate cross-correlation}
\usage{
getExperimentCrossCorrelation(x, ...)

\S4method{getExperimentCrossCorrelation}{MultiAssayExperiment}(
  x,
  experiment1 = 1,
  experiment2 = 2,
  abund_values1 = "counts",
  abund_values2 = "counts",
  method = c("spearman", "categorical", "kendall", "pearson"),
  mode = "table",
  p_adj_method = c("fdr", "BH", "bonferroni", "BY", "hochberg", "holm", "hommel",
    "none"),
  p_adj_threshold = 0.05,
  cor_threshold = NULL,
  sort = FALSE,
  filter_self_correlations = FALSE,
  verbose = TRUE,
  ...
)

\S4method{getExperimentCrossCorrelation}{SummarizedExperiment}(x, experiment2 = x, ...)

testForExperimentCrossCorrelation(x, ...)

\S4method{testForExperimentCrossCorrelation}{ANY}(x, ...)
}
\arguments{
\item{x}{A
\code{\link[MultiAssayExperiment:MultiAssayExperiment-class]{MultiAssayExperiment}} or
\code{\link[SummarizedExperiment:SummarizedExperiment-class]{SummarizedExperiment}}
object.}

\item{...}{Additional arguments:
\itemize{
\item{\code{test_significance}}{A single boolean value
in function \code{getExperimentCrossCorrelation} for selecting
whether to test significance or not.
(By default: \code{test_significance = FALSE})}
}}

\item{experiment1}{A single character or numeric value for selecting the experiment 1
from \code{experiments(x)} of \code{MultiassayExperiment} object.
(By default: \code{experiment1 = 1})}

\item{experiment2}{A single character or numeric value for selecting the experiment 2
from\code{experiments(x)} of \code{MultiAssayExperiment} object or
\code{altExp(x)} of \code{SummarizedExperiment} object. Alternatively,
\code{experiment2} can also be \code{SE} object when \code{x} is \code{SE} object.
(By default: \code{experiment2 = 2} when \code{x} is \code{MAE} and
\code{experiment2 = x} when \code{x} is \code{SE})}

\item{abund_values1}{A single character value for selecting the
\code{\link[SummarizedExperiment:SummarizedExperiment-class]{assay}} of
experiment 1 to be transformed. (By default: \code{abund_values1 = "counts"})}

\item{abund_values2}{A single character value for selecting the
\code{\link[SummarizedExperiment:SummarizedExperiment-class]{assay}} of
experiment 2 to be transformed. (By default: \code{abund_values2 = "counts"})}

\item{method}{A single character value for selecting association method
('kendall', pearson', or 'spearman' for continuous/numeric; 'categorical' for discrete)
(By default: \code{method = "spearman"})}

\item{mode}{A single character value for selecting output format
Available formats are  'table' and 'matrix'.  (By default: \code{mode = "table"})}

\item{p_adj_method}{A single character value for selecting adjustment method of
p-values. Passed to \code{p.adjust} function.
(By default: \code{p_adj_method = "fdr"})}

\item{p_adj_threshold}{A single numeric value (from 0 to  1) for selecting
adjusted p-value threshold. (By default: \code{p_adj_threshold = 0.05})}

\item{cor_threshold}{A single numeric absolute value (from 0 to 1]) for selecting
correlation threshold to include features. (By default: \code{cor_threshold = NULL})}

\item{sort}{A single boolean value for selecting whether to sort features or not
in result matrices. Used method is hierarchical clustering.
Disabled when \code{mode = "table"}. (By default: \code{sort = FALSE})}

\item{filter_self_correlations}{A single boolean value for selecting whether to
filter out correlations between identical items. Applies only when correlation
between experiment itself is tested, i.e., when assays are identical.
(By default: \code{filter_self_correlations = FALSE})}

\item{verbose}{A single boolean value for selecting whether to get messages
about progress of calculation.}
}
\value{
These functions return associations in table or matrix format. In table format,
returned value is a data frame that includes  features and associations
(and p-values) in columns. In matrix format, returned value is a one matrix
when only associations are calculated. If also significances are tested, then
returned value is a list of matrices.
}
\description{
Calculate cross-correlation
}
\details{
These functions calculates associations between features of two experiments.
\code{getExperimentCrossCorrelation} calculates only associations by default.
\code{testForExperimentCrossCorrelation} calculates also significance of
associations.
}
\examples{
mae <- microbiomeDataSets::peerj32()

# Subset so that less observations / quicker to run, just for example
mae[[1]] <- mae[[1]][1:20, 1:10]
mae[[2]] <- mae[[2]][1:20, 1:10]
# Calculate cross-correlations
result <- getExperimentCrossCorrelation(mae, method = "pearson")
# Show first 5 entries
head(result, 5)

# Same can be done with SummarizedExperiment and altExp
# Create TreeSE with altExp
tse <- mae[[1]]
altExp(tse, "exp2") <- mae[[2]]
# Whe mode = matrix, matrix is returned
result <- getExperimentCrossCorrelation(tse,
                                        experiment2 = "exp2",
                                        method = "pearson", 
                                        mode = "matrix")
# Show first 5 entries
head(result, 5)

# testForExperimentCorrelation returns also significances
# filter_self_correlations = TRUE filters self correlations
result <- testForExperimentCrossCorrelation(tse,
                                            experiment2 = tse,
                                            method = "pearson",
                                            filter_self_correlations = TRUE)
# Show first 5 entries
head(result, 5)

# Also getExperimentCrossCorrelation returns significances when 
# test_signicance = TRUE
result <- getExperimentCrossCorrelation(mae[[1]],
                                        experiment2 = mae[[2]],
                                        method = "pearson",
                                        mode = "matrix",
                                        test_significance = TRUE)
# Returned value is a list of matrices
names(result)
}
\author{
Leo Lahti and Tuomas Borman. Contact: \url{microbiome.github.io}
}
